// 语音播报模块

import { httpGet, httpPost } from "@/utils/request.js";

/**
 * 语音列表
 * @param page_index 
 * @param page_size
 * @param broadcast_id 语音id
 * @param section_id 板块id
 * @param author_id 作者ID（我的语音播报列表）
 * @param mine_status 语音播报状态：0-未发布 1-已发布 2-全部（我的语音播报列表）
 */
export const apiVoiceList=params=>{
    return httpPost('/voice/broadcast/list',params)
}

/**
 * 语音板块列表
 */
export const apiVoiceSectionList=()=>{
    return httpGet('/voice/broadcast/section/list',{})
}

/**
 * 删除语音
 * @param broadcast_id
 */
export const apiVoiceDel=params=>{
    return httpGet('/voice/broadcast/delete',params)
}

/**
 * 播放记录
 * @param broadcast_id
 * @param source 来源平台：1:小程序、2:小程序(pc)、3:公众号、4:官网web(pc)
 */
export const apiVoicePlayRecord=params=>{
    return httpPost('/voice/broadcast/statistics/add',{...params,source:1})
}

/**
 * 语音详情
 * @param broadcast_id
 */
export const apiVoiceDetail=params=>{
    return httpGet('/voice/broadcast/detail',params)
}

/**
 * 推送客群、模板消息
 * @param broadcast_id
 */
export const apiVoiceSendMsg=params=>{
    return httpPost('/voice/broadcast/msg_send',params)
}

/**
 * 新增语音
 * @param broadcast_name 语音标题
 * @param section_id 板块ID
 * @param section_name 板块名称
 * @param variety_id 品种ID
 * @param variety_name 品种名称
 * @param author_id 作者ID
 * @param author 作者名称
 * @param imgs 图片：英文逗号拼接
 * @param voice_seconds 音频时长
 * @param voice_size 音频大小
 * @param voice_url 音频地址
 */
export const apiVoiceAdd=params=>{
    return httpPost('/voice/broadcast/add',params)
}

/**
 * 编辑语音
 * @param broadcast_id 语音播报ID
 * @param broadcast_name 语音标题
 * @param section_id 板块ID
 * @param section_name 板块名称
 * @param variety_id 品种ID
 * @param variety_name 品种名称
 * @param author_id 作者ID
 * @param author 作者名称
 * @param imgs 图片：英文逗号拼接
 * @param voice_seconds 音频时长
 * @param voice_size 音频大小
 * @param voice_url 音频地址
 */
export const apiVoiceEdit=params=>{
    return httpPost('/voice/broadcast/edit',params)
}

/**
 * 发布语音
 * @param broadcast_id 语音播报ID
 * @param publish_type 发布类型：1-发布 2-定时发布
 * @param pre_publish_time 预发布时间（类型为定时发布时必填）
 */
export const apiVoicePublish=params=>{
    return httpPost('/voice/broadcast/publish',params)
}

/**
 * 我的语音数量统计
 * @param author_id
 */
export const apiMyVoiceCount=params=>{
    return httpGet('/voice/broadcast/list_count',params)
}